pub struct LedgerParameters {
pub cost_model: TransactionCostModel,
pub limits: TransactionLimits,
pub dust: DustParameters,
pub fee_prices: FeePrices,
pub global_ttl: Duration,
pub cost_dimension_min_ratio: FixedPoint,
pub price_adjustment_a_parameter: FixedPoint,
pub cardano_to_midnight_bridge_fee_basis_points: u32,
pub c_to_m_bridge_min_amount: u128,
}Fields
cost_model: TransactionCostModellimits: TransactionLimitsdust: DustParametersfee_prices: FeePricesglobal_ttl: Durationcost_dimension_min_ratio: FixedPointprice_adjustment_a_parameter: FixedPointcardano_to_midnight_bridge_fee_basis_points: u32c_to_m_bridge_min_amount: u128Implementations
Sourceimpl LedgerParameters
impl LedgerParameters
Sourcepub fn max_price_adjustment(&self) -> FixedPoint
pub fn max_price_adjustment(&self) -> FixedPoint
The maximum price adjustment per block with the current parameters, as a multiplicative factor (that is: 1.1 would indicate a 10% adjustment). Will always return the positive (>1) adjustment factor. Note that negative adjustments are the additive inverse (1.1 has a corresponding 0.9 downward adjustment), not the multiplicative as might reasonably be assumed.
pub fn min_claimable_rewards(&self) -> u128