pub struct TransactionLimits {
pub transaction_byte_limit: u64,
pub time_to_dismiss_per_byte: CostDuration,
pub min_time_to_dismiss: CostDuration,
pub block_limits: SyntheticCost,
pub block_withdrawal_minimum_multiple: FixedPoint,
}Fields
transaction_byte_limit: u64time_to_dismiss_per_byte: CostDurationmin_time_to_dismiss: CostDurationblock_limits: SyntheticCostblock_withdrawal_minimum_multiple: FixedPointThe minimum amount of Night withdrawable from block rewards, as a multiple of the amount which would be able to pay the theoretical fees for the withdrawal when Dust reaches its cap.